==> odoo14_addon_energy_communities-14.0.9.2.1-py2.py3-none-any.whl: odoo/addons/energy_communities/__manifest__.py <==
{
    "name": "Energy Community",
    "version": "14.0.9.2.1",
    "depends": [
        "account",
        "cooperator_account_banking_mandate",
        "account_lock_date_update",
        "account_multicompany_easy_creation",
        "cooperator_account_payment",
        "account_payment_order",
        "account_reconciliation_widget",
        "auth_api_key",
        "auth_oauth",
        "auth_oidc",
        "auth_signup",
        "base_rest",
        "base_technical_features",
        "base_user_role",
        "base_user_role_company",
        "community_maps",
        "contacts",
        "cooperator",
        "energy_selfconsumption",
        "event",
        "l10n_es_aeat",
        "l10n_es_aeat_sii_oca",
        "l10n_es_cooperator",
        "mail_multicompany",
        "mass_mailing",
        "metadata",
        "partner_multi_company",
        "purchase",
        "queue_job",
        "sale_crm",
        "sale_management",
        "sales_team",
        "website_event",
    ],
    "author": "Coopdevs Treball SCCL & Som Energia SCCL",
    "website": "https://coopdevs.org",
    "category": "Cooperative management",
    "description": """
    Energy Communities customizations.
    """,
    "license": "AGPL-3",
    "demo": [
        "demo/res_lang_demo.xml",
        "demo/res_company_demo.xml",
        "demo/res_user_demo.xml",
        "demo/subscription_request_demo.xml",
        "demo/energy_selfconsumption_demo.xml",
    ],
    "data": [
        "security/ir_rule_data.xml",
        "security/res_users_role_data.xml",
        "security/ir.model.access.csv",
        "data/product_data.xml",
        "data/auth_oauth_provider_data.xml",
        "data/ir_cron.xml",
        "data/utm_data.xml",
        "data/crm_lead_tag.xml",
        "report/report_templates.xml",
        "views/account_move_views.xml",
        "views/landing_page_view.xml",
        "views/res_company_views.xml",
        "views/res_config_settings.xml",
        "views/res_partner_views.xml",
        "views/ce_views.xml",
        "views/cm_place.xml",
        "views/utm_views.xml",
        "views/auth_oauth_views.xml",
        "views/view_users_form.xml",
        "views/product_views.xml",
        "views/res_users_view.xml",
        "views/res_users_role_view.xml",
        "views/menus.xml",
        "views/website_formfields_template.xml",
        "views/website_subscription_template.xml",
        "views/account_banking_mandate_views.xml",
        "data/mail_template_update_data.xml",
        "data/community_maps_data.xml",
        "wizards/multicompany_easy_creation.xml",
        "wizards/assign_admin_wizard.xml",
        "wizards/change_coordinator_wizard.xml",
    ],
    "installable": True,
    "application": True,
    "auto_install": False,
    "post_init_hook": "post_init_hook",
}

==> odoo14_addon_energy_communities-14.0.9.3.0-py2.py3-none-any.whl: odoo/addons/energy_communities/__manifest__.py <==
{
    "name": "Energy Community",
    "version": "14.0.9.3.0",
    "depends": [
        "account",
        "account_banking_mandate",
        "account_lock_date_update",
        "account_multicompany_easy_creation",
        "account_payment_order",
        "account_reconciliation_widget",
        "auth_api_key",
        "auth_oidc",
        "auth_signup",
        "base_rest",
        "base_technical_features",
        "base_user_role",
        "base_user_role_company",
        "community_maps",
        "contacts",
        "event",
        "l10n_es_aeat",
        "l10n_es_aeat_sii_oca",
        "mail_multicompany",
        "metadata",
        "partner_firstname",
        "partner_multi_company",
        "purchase",
        "queue_job",
        "sale_management",
        "sales_team",
        "website_event",
    ],
    "author": "Coopdevs Treball SCCL & Som Energia SCCL",
    "website": "https://coopdevs.org",
    "category": "Cooperative management",
    "description": """
    Energy Communities customizations.
    """,
    "license": "AGPL-3",
    "demo": [
        "demo/res_lang_demo.xml",
        "demo/res_company_demo.xml",
        "demo/res_partner_demo.xml",
        "demo/res_user_demo.xml",
    ],
    "data": [
        "security/ir.model.access.csv",
        "security/ir_rule_data.xml",
        "security/res_users_role_data.xml",
        "data/product_data.xml",
        "data/auth_oauth_provider_data.xml",
        "data/ir_cron.xml",
        "data/utm_data.xml",
        "data/crm_lead_tag.xml",
        "report/report_templates.xml",
        "views/account_move_views.xml",
        "views/landing_page_view.xml",
        "views/res_company_views.xml",
        "views/res_config_settings.xml",
        "views/res_partner_views.xml",
        "views/ce_views.xml",
        "views/cm_place.xml",
        "views/utm_views.xml",
        "views/auth_oauth_views.xml",
        "views/view_users_form.xml",
        "views/product_views.xml",
        "views/res_users_view.xml",
        "views/res_users_role_view.xml",
        "views/menus.xml",
        "views/website_formfields_template.xml",
        "views/account_banking_mandate_views.xml",
        "data/community_maps_data.xml",
        "wizards/multicompany_easy_creation.xml",
        "wizards/assign_admin_wizard.xml",
        "wizards/create_users_wizard.xml",
        "wizards/change_coordinator_wizard.xml",
    ],
    "installable": True,
    "application": True,
    "auto_install": False,
    "post_init_hook": "post_init_hook",
}
